@@ -253,7 +253,7 @@ class SignalContainer(np.ndarray):
             if not isinstance(item, slice) or self._nonstandard_x_axis is not None:
                 res._nonstandard_x_axis = self.x_axis[item]  # nonstandard choice of indices
             else:
-                res.x_start = self.x_axis[item][0]
+                res.x_start = self.x_axis[item][0] if res.size else (self.x_axis[0] if self.size else 0)
                 if item.step is not None:
                     res._base_resolution *= item.step
 
@@ -277,7 +277,7 @@ class SignalContainer(np.ndarray):
             return self._nonstandard_x_axis
 
         x0 = self.x_start if self.x_start is not None else 0
-        return x0 + np.arange(self.shape[0]) * self.resolution
+        return x0 + np.arange(self.shape[-1]) * self.resolution
 
     @x_axis.setter
     def x_axis(self, val):
@@ -287,7 +287,7 @@ class SignalContainer(np.ndarray):
         if not isinstance(val, (abc.Sequence, abc.Iterable)):
             raise TypeError("x axis should be a sequence")
 
-        if not len(val) == self.shape[0]:
+        if not len(val) == self.shape[-1]:
             raise ValueError(f"Length of the x axis ({len(val)}) does not match the signal shape ({self.shape})")
 
         self._nonstandard_x_axis = np.array(val)
@@ -361,6 +361,9 @@ class SignalContainer(np.ndarray):
             additional keyword arguments passed to the specific plotting methods (or matplotlib.pyplot.plot)
         """
 
+        if self.size < 2:
+            kwargs['marker'] = kwargs.get('marker', 'o')  # put a single dot if there is only one data point
+
         if np.iscomplexobj(self):
             if complex_plot == 'bode':
                 fig, axes = self._display_complex_bode(**kwargs)
